@@ -32,7 +32,7 @@
 #define SPACE1_DIM1    4
 #define NUMP           4
 
-#define VLSTR_TYPE      "vl_string_type"
+#define VLSTR_TYPE  "vl_string_type"
 
 /* Definitions for the VL re-writing test */
 #define REWRITE_NDATASETS       32
@@ -94,7 +94,7 @@ void test_vlstr_free_custom(void *_mem, void *info)
 
     if(_mem!=NULL) {
         mem=((unsigned char *)_mem)-extra;
-        *mem_used-=*(size_t *)mem;
+        *mem_used-=*(size_t *)((void *)mem);
         HDfree(mem);
     } /* end if */
 }
@@ -183,7 +183,7 @@ test_vlstrings_basic(void)
 
     /* Count the actual number of bytes used by the strings */
     for(i=0,str_used=0; i<SPACE1_DIM1; i++)
-        str_used+=HDstrlen(wdata[i])+1;
+        str_used += HDstrlen(wdata[i])+1;
 
     /* Compare against the strings actually written */
     VERIFY(size,(hsize_t)str_used,"H5Dvlen_get_buf_size");
@@ -198,7 +198,7 @@ test_vlstrings_basic(void)
     /* Compare data read in */
     for(i = 0; i < SPACE1_DIM1; i++) {
         if(HDstrlen(wdata[i]) != HDstrlen(rdata[i])) {
-            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)strlen(rdata[i]));
+            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)HDstrlen(rdata[i]));
             continue;
         } /* end if */
         if(HDstrcmp(wdata[i], rdata[i]) != 0 ) {
@@ -300,7 +300,7 @@ test_vlstrings_special(void)
     /* Compare data read in */
     for(i = 0; i < SPACE1_DIM1; i++) {
         if(HDstrlen(wdata[i]) != HDstrlen(rdata[i])) {
-            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)strlen(rdata[i]));
+            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)HDstrlen(rdata[i]));
             continue;
         } /* end if */
         if((wdata[i] == NULL && rdata[i] != NULL) || (rdata[i] == NULL && wdata[i] != NULL)) {
@@ -527,7 +527,7 @@ test_compact_vlstring(void)
     /* Compare data read in */
     for(i = 0; i < SPACE1_DIM1; i++) {
         if(HDstrlen(wdata[i]) != HDstrlen(rdata[i])) {
-            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)strlen(rdata[i]));
+            TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)HDstrlen(rdata[i]));
             continue;
         } /* end if */
         if(HDstrcmp(wdata[i], rdata[i]) != 0) {
@@ -802,33 +802,33 @@ static void test_vl_rewrite(void)
 
     /* Create in file 1 */
     for(i=0; i<REWRITE_NDATASETS; i++) {
-        sprintf(name, "/set_%d", i);
+        HDsprintf(name, "/set_%d", i);
         write_scalar_dset(file1, type, space, name, name);
     }
 
     /* Effectively copy data from file 1 to 2 */
     for(i=0; i<REWRITE_NDATASETS; i++) {
-        sprintf(name, "/set_%d", i);
+        HDsprintf(name, "/set_%d", i);
         read_scalar_dset(file1, type, space, name, name);
         write_scalar_dset(file2, type, space, name, name);
     }
 
     /* Read back from file 2 */
     for(i = 0; i < REWRITE_NDATASETS; i++) {
-        sprintf(name, "/set_%d", i);
+        HDsprintf(name, "/set_%d", i);
         read_scalar_dset(file2, type, space, name, name);
     } /* end for */
 
     /* Remove from file 2. */
     for(i = 0; i < REWRITE_NDATASETS; i++) {
-        sprintf(name, "/set_%d", i);
+        HDsprintf(name, "/set_%d", i);
         ret = H5Ldelete(file2, name, H5P_DEFAULT);
         CHECK(ret, FAIL, "H5Ldelete");
     } /* end for */
 
     /* Effectively copy from file 1 to file 2 */
     for(i = 0; i < REWRITE_NDATASETS; i++) {
-        sprintf(name, "/set_%d", i);
+        HDsprintf(name, "/set_%d", i);
         read_scalar_dset(file1, type, space, name, name);
         write_scalar_dset(file2, type, space, name, name);
     } /* end for */
@@ -882,7 +882,7 @@ static void test_write_same_element(void)
 
     dataset1 = H5Dcreate2(file1, DATASET, dtype, fspace, H5P_DEFAULT,
                           H5P_DEFAULT, H5P_DEFAULT);
-    CHECK(dataset1, FAIL, "H5Dcreate2");
+    CHECK(dataset1, FAIL, "H5Dcreate");
 
     ret = H5Dwrite(dataset1, dtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, wdata);
     CHECK(ret, FAIL, "H5Dwrite");
@@ -906,7 +906,7 @@ static void test_write_same_element(void)
     CHECK(file1, FAIL, "H5Fopen");
 
     dataset1 = H5Dopen2(file1, DATASET, H5P_DEFAULT);
-    CHECK(dataset1, FAIL, "H5Dopen2");
+    CHECK(dataset1, FAIL, "H5Dopen");
 
     fspace = H5Dget_space(dataset1);
     CHECK(fspace, FAIL, "H5Dget_space");
@@ -972,7 +972,6 @@ test_vlstrings(void)
     test_write_same_element();
 }   /* test_vlstrings() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    cleanup_vlstrings
  *
